#region Using declarations
using System;
using System.ComponentModel;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Data;
using NinjaTrader.Indicator;
using NinjaTrader.Gui.Chart;
using NinjaTrader.Strategy;
#endregion

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Strategy
{
    /// <summary>
    /// Example of using GomOrderFlowLevels in a strategy
    /// </summary>
    [Description("Example of using GomOrderFlowLevels in a strategy")]
    public class GomOFNakedPOCSampleStrat : Strategy
    {
        #region Variables
        
		// Wizard generated variables
        private int target = 10; // Default setting for Target
        private int stop = 10; // Default setting for Stop
		private int minimumAge=5; 
        // User defined variables (add any user defined variables below)
		private GomOrderFlowProLevels gofl;
        
		#endregion


		
        /// <summary>
        /// This method is used to configure the strategy and is called once before any strategy method is called.
        /// </summary>
        protected override void Initialize()
        {
            SetProfitTarget("L", CalculationMode.Ticks, Target);
            SetStopLoss("L", CalculationMode.Ticks, Stop, false);

            CalculateOnBarClose = true;
			
			// you can use the ninja strategy builder to get the correct initializer
			// here are the enums:
			
			// public enum DeltaCalcType {BidAsk,UpDownTick};
			// public enum ImbalanceComparisonType { Ratio, Difference };
			// public enum ImbalanceTypeType { Diagonal, Horizontal, Both };
			// public enum SRZoneEndConditionType { FullCandleCross, SimpleCross, PocCross };

			gofl=GomOrderFlowProLevels(Gom.DeltaLib.DeltaCalcType.UpDownTick, Gom.OrderFlow.ImbalanceComparisonType.Ratio,Gom.OrderFlow.ImbalanceDirectionType.Diagonal, 3, Gom.OrderFlow.ImbalanceComparisonType.Ratio,Gom.OrderFlow.ImbalanceDirectionType.None, 3, -1, 0, -1,0,false, false, Gom.OrderFlow.SRZoneEndConditionType.FullCandleCross, 1, 0, 3, 1);

        }

        /// <summary>
        /// Called on each bar update event (incoming tick)
        /// </summary>
        protected override void OnBarUpdate()
        {
			if (FirstTickOfBar)
			{
				gofl.Update();
				
				double price=0;
				bool found=false;
				
				// for each level like NakedPOCLow1, we have to check is the data series actually contains a number.
				// NakedPOCLow1BarsAgo contains the "age" of the naked poc, ie how many bars ago it was created.
				
				if ((	gofl.NakedPOCLow1.ContainsValue(0) && // check if is value is populated
						gofl.NakedPOCLow1BarsAgo[0] >=MinimumAge)) // check if poc is old enough
				{
					found=true;
					price=gofl.NakedPOCLow1[0]; // get the poc
				}
				
				//same for second level
				else if ((	gofl.NakedPOCLow2.ContainsValue(0) && // check if is value is populated
							gofl.NakedPOCLow2BarsAgo[0] >=MinimumAge)) // check if poc is old enough
				{
					found=true;
					price=gofl.NakedPOCLow2[0]; // get the poc
				}
				
				// etc etc all levels can be checked
							
				
				if (found)
	            	EnterLongLimit(DefaultQuantity,price, "L");
			}
        }

        #region Properties
        [Description("")]
        [GridCategory("Parameters")]
        public int Target
        {
            get { return target; }
            set { target = Math.Max(1, value); }
        }

        [Description("")]
        [GridCategory("Parameters")]
        public int Stop
        {
            get { return stop; }
            set { stop = Math.Max(1, value); }
        }
		
		[Description("")]
        [GridCategory("Parameters")]
        public int MinimumAge
        {
            get { return minimumAge; }
            set { minimumAge = Math.Max(1, value); }
        }
        #endregion
    }
}
